@@ -28,7 +28,8 @@ enum cntrl_type {
 	CNTRL_TYPE_DELLSSD,
 	CNTRL_TYPE_VMD,
 	CNTRL_TYPE_SCSI,
-	CNTRL_TYPE_AHCI
+	CNTRL_TYPE_AHCI,
+	CNTRL_TYPE_AMD_SGPIO
 };
 
 /**
